@@ -2,6 +2,7 @@ from typing import List
 from pydantic.dataclasses import dataclass
 from .invoice_profile import InvoiceProfile
 from .emergency_contact import EmergencyContact
+from .travel_document import TravelDocument
 
 
 @dataclass
@@ -12,3 +13,4 @@ class TravelperkExtension:
     date_of_birth: str = None
     travel_policy: str = None
     country_of_residence: str = None
+    travel_documents: List[TravelDocument] = None
